@@ -35,13 +35,15 @@ class GaugeVar;
 class CounterVar;
 class HistogramVar;
 class SummaryVar;
+class HistogramCounterVar;
 
 enum RPCVarType
 {
-	VAR_GAUGE		=	0,
-	VAR_COUNTER		=	1,
-	VAR_HISTOGRAM	=	2,
-	VAR_SUMMARY		=	3
+	VAR_GAUGE				=	0,
+	VAR_COUNTER				=	1,
+	VAR_HISTOGRAM			=	2,
+	VAR_SUMMARY				=	3,
+	VAR_HISTOGRAM_COUNTER	=	4
 };
 
 static std::string type_string(RPCVarType type)
@@ -53,6 +55,7 @@ static std::string type_string(RPCVarType type)
 	case VAR_COUNTER:
 		return "counter";
 	case VAR_HISTOGRAM:
+	case VAR_HISTOGRAM_COUNTER:
 		return "histogram";
 	case VAR_SUMMARY:
 		return "summary";
@@ -74,6 +77,8 @@ public:
 
 	static SummaryVar *summary(const std::string& name);
 
+	static HistogramCounterVar *histogram_counter(const std::string &name);
+
 	static RPCVar *var(const std::string& name);
 	static bool check_name_format(const std::string& name);
 };
@@ -111,7 +116,6 @@ public:
 	std::mutex mutex;
 	std::vector<RPCVarLocal *> local_vars;
 	bool finished;
-//	friend class RPCVarFactory;
 };
 
 class RPCVarLocal
@@ -146,7 +150,6 @@ public:
 	std::mutex mutex;
 	std::unordered_map<std::string, RPCVar *> vars;
 	friend class RPCVarGlobal;
-//	friend class RPCVarFactory;
 };
 
 class RPCVarCollector
@@ -249,28 +252,31 @@ class CounterVar : public RPCVar
 public:
 	using LABEL_MAP = std::map<std::string, std::string>;
 	GaugeVar *add(const LABEL_MAP& labels);
+	void increase(const LABEL_MAP& labels);
+	void increase(const LABEL_MAP &labels, double value);
 
 	RPCVar *create(bool with_data) override;
 	bool reduce(const void *ptr, size_t sz) override;
 	void collect(RPCVarCollector *collector) override;
 
 	size_t get_size() const override { return this->data.size(); }
-	const void *get_data() override { return &this->data; }
-
-	static bool label_to_str(const LABEL_MAP& labels, std::string& str);
+	const void *get_data() override { return this; }
+	const std::unordered_map<std::string, GaugeVar *> *get_map() const
+	{
+		return &this->data;
+	}
+	double get_sum() const { return this->sum; }
+	void increase_sum(double value) { this->sum += value; }
 
 	void reset() override;
 
 public:
-	CounterVar(const std::string& name, const std::string& help) :
-		RPCVar(name, help, VAR_COUNTER)
-	{
-	}
-
-	~CounterVar();
+	CounterVar(const std::string &name, const std::string &help);
+	virtual ~CounterVar();
 
 private:
 	std::unordered_map<std::string, GaugeVar *> data;
+	double sum;
 };
 
 class HistogramVar : public RPCVar
@@ -290,6 +296,10 @@ public:
 
 	double get_sum() const { return this->sum; }
 	size_t get_count() const { return this->count; }
+	const std::vector<double> *get_bucket_boundaries() const
+	{
+		return &this->bucket_boundaries;
+	}
 	const std::vector<size_t> *get_bucket_counts() const
 	{
 		return &this->bucket_counts;
@@ -327,7 +337,19 @@ public:
 		return &this->quantile_values;
 	}
 
-	void reset() override { /* no TimedSummary so no reset for Summary */}
+	void reset() override { /* TODO: incorrect if reset() by report interval */ }
+
+	const std::vector<struct Quantile>& get_quantiles() const
+	{
+		return this->quantiles;
+	}
+	const std::vector<double>& get_quantile_out() const
+	{
+		return this->quantile_out;
+	}
+
+	// only for clear stack variable after filled into protobuf or out_string
+	void clear_quantile_out() { this->quantile_out.clear(); }
 
 public:
 	SummaryVar(const std::string& name, const std::string& help,
@@ -401,11 +423,43 @@ public:
 				  Clock::duration duration, size_t bucket_num);
 	// for collect
 	void increase() override;
+	double get() override;
+	void set(double var) override;
+
 	// for reduce
 	const void *get_data() override;
 	RPCVar *create(bool with_data) override;
 };
 
+class HistogramCounterVar : public RPCVar
+{
+public:
+	using LABEL_MAP = std::map<std::string, std::string>;
+	void observe(const LABEL_MAP &labels, double value);
+
+	RPCVar *create(bool with_data) override;
+	bool reduce(const void *ptr, size_t sz) override;
+	void collect(RPCVarCollector *collector) override;
+
+	size_t get_size() const override { return this->data.size(); }
+	const void *get_data() override { return this; }
+	const std::unordered_map<std::string, HistogramVar *> *get_map() const
+	{
+		return &this->data;
+	}
+
+	void reset() override;
+
+public:
+	HistogramCounterVar(const std::string &name, const std::string &help,
+						const std::vector<double> &bucket);
+	virtual ~HistogramCounterVar();
+
+private:
+	std::unordered_map<std::string, HistogramVar *> data;
+	std::vector<double> bucket;
+};
+
 } // end namespace srpc
 
 #endif
