@@ -27,7 +27,8 @@
 #include "rpc_meta.pb.h"
 #include "rpc_message_srpc.h"
 #include "rpc_zero_copy_stream.h"
-#include "rpc_module_span.h"
+#include "rpc_module.h"
+#include "rpc_trace_module.h"
 
 namespace srpc
 {
@@ -963,83 +964,24 @@ bool SRPCHttpResponse::deserialize_meta()
 	return __deserialize_meta_http(NULL, this, this, this->meta);
 }
 
-static bool __set_meta_module_data(const RPCModuleData& data,
-								   protocol::HttpMessage *http_msg)
-{
-	auto it = data.begin();
-	int flag = 0;
-
-	while (it != data.end() && flag != 3)
-	{
-		if (it->first == SRPC_TRACE_ID)
-		{
-			char trace_id_buf[SRPC_TRACEID_SIZE * 2 + 1];
-			TRACE_ID_BIN_TO_HEX((uint64_t *)it->second.c_str(), trace_id_buf);
-			http_msg->set_header_pair("Trace-Id", trace_id_buf);
-			flag |= 1;
-		}
-		else if (it->first == SRPC_SPAN_ID)
-		{
-			char span_id_buf[SRPC_SPANID_SIZE * 2 + 1];
-			SPAN_ID_BIN_TO_HEX((uint64_t *)it->second.c_str(), span_id_buf);
-			http_msg->set_header_pair("Span-Id", span_id_buf);
-			flag |= (1 << 1);
-		}
-		++it;
-	}
-
-	return true;
-}
-
-static bool __get_meta_module_data(RPCModuleData& data,
-								   const protocol::HttpMessage *http_msg)
-{
-	protocol::HttpHeaderCursor cursor(http_msg);
-	std::string name;
-	std::string value;
-	int flag = 0;
-
-	while (cursor.next(name, value) && flag != 3)
-	{
-		if (strcasecmp(name.c_str(), "Trace-Id") == 0 &&
-			value.size() == SRPC_TRACEID_SIZE * 2)
-		{
-			uint64_t trace_id[2];
-			TRACE_ID_HEX_TO_BIN(value.c_str(), trace_id);
-			data[SRPC_TRACE_ID] = std::string((char *)trace_id, SRPC_TRACEID_SIZE);
-			flag |= 1;
-		}
-		else if (strcasecmp(name.c_str(), "Span-Id") == 0 &&
-				 value.size() == SRPC_SPANID_SIZE * 2)
-		{
-			uint64_t span_id[1];
-			SPAN_ID_HEX_TO_BIN(value.c_str(), span_id);
-			data[SRPC_SPAN_ID] = std::string((char *)span_id, SRPC_SPANID_SIZE);
-			flag |= (1 << 1);
-		}
-	}
-
-	return true;
-}
-
 bool SRPCHttpRequest::set_meta_module_data(const RPCModuleData& data)
 {
-	return __set_meta_module_data(data, this);
+	return http_set_header_module_data(data, this);
 }
 
 bool SRPCHttpRequest::get_meta_module_data(RPCModuleData& data) const
 {
-	return __get_meta_module_data(data, this);
+	return http_get_header_module_data(this, data);
 }
 
 bool SRPCHttpResponse::set_meta_module_data(const RPCModuleData& data)
 {
-	return __set_meta_module_data(data, this);
+	return http_set_header_module_data(data, this);
 }
 
 bool SRPCHttpResponse::get_meta_module_data(RPCModuleData& data) const
 {
-	return __get_meta_module_data(data, this);
+	return http_get_header_module_data(this, data);
 }
 
 bool SRPCHttpRequest::set_http_header(const std::string& name,
