@@ -53,6 +53,8 @@ int main()
 
 	if (server.start(1412) == 0)
 	{
+		printf("SRPC framework SRPC Protobuf server is running on 1412\n"
+			   "Try ./srpc_pb_client to send requests.\n\n");
 		wait_group.wait();
 		server.stop();
 	}
