@@ -63,7 +63,8 @@ int main()
 
 	if (server.start(1412) == 0)
 	{
-		printf("SRPC framework TRPCHttp server running on 1412...\n");
+		printf("SRPC framework TRPCHttp server is running on 1412\n"
+			   "Try ./trpc_http_client to send requests.\n\n");
 		wait_group.wait();
 		server.stop();
 	}
